@@ -41,9 +41,12 @@ void CliRarTest::initTestCase()
 {
     qRegisterMetaType<ArchiveEntry>();
 
-    const auto plugins = KPluginLoader::findPluginsById(QStringLiteral("kerfuffle"), QStringLiteral("kerfuffle_clirar"));
-    if (plugins.size() == 1) {
-        m_pluginMetadata = plugins.at(0);
+    m_plugin = new Plugin(this);
+    foreach (Plugin *plugin, m_pluginManger.availablePlugins()) {
+        if (plugin->metaData().pluginId() == QStringLiteral("kerfuffle_clirar")) {
+            m_plugin = plugin;
+            return;
+        }
     }
 }
 
@@ -66,12 +69,12 @@ void CliRarTest::testArchive_data()
 
 void CliRarTest::testArchive()
 {
-    if (!m_pluginMetadata.isValid()) {
-        QSKIP("Could not find the clirar plugin. Skipping test.", SkipSingle);
+    if (!m_plugin->isValid()) {
+        QSKIP("clirar plugin not available. Skipping test.", SkipSingle);
     }
 
     QFETCH(QString, archivePath);
-    Archive *archive = Archive::create(archivePath, m_pluginMetadata, this);
+    Archive *archive = Archive::create(archivePath, m_plugin, this);
     QVERIFY(archive);
 
     if (!archive->isValid()) {
@@ -98,6 +101,9 @@ void CliRarTest::testList_data()
 {
     QTest::addColumn<QString>("outputTextFile");
     QTest::addColumn<int>("expectedEntriesCount");
+    QTest::addColumn<bool>("isMultiVolume");
+    // Is zero for non-multi-volume archives:
+    QTest::addColumn<int>("numberOfVolumes");
     // Index of some entry to be tested.
     QTest::addColumn<int>("someEntryIndex");
     // Entry metadata.
@@ -112,47 +118,57 @@ void CliRarTest::testList_data()
     // Unrar 5 tests
 
     QTest::newRow("normal-file-unrar5")
-            << QFINDTESTDATA("data/archive-with-symlink-unrar5.txt") << 8
+            << QFINDTESTDATA("data/archive-with-symlink-unrar5.txt") << 8 << false << 0
             << 2 << QStringLiteral("rartest/file2.txt") << false << false << QString() << (qulonglong) 14 << (qulonglong) 23 << QStringLiteral("2016-03-21T08:57:36");
 
     QTest::newRow("symlink-unrar5")
-            << QFINDTESTDATA("data/archive-with-symlink-unrar5.txt") << 8
+            << QFINDTESTDATA("data/archive-with-symlink-unrar5.txt") << 8 << false << 0
             << 3 << QStringLiteral("rartest/linktofile1.txt") << false << false << QStringLiteral("file1.txt") << (qulonglong) 9 << (qulonglong) 9 << QStringLiteral("2016-03-21T08:58:16");
 
     QTest::newRow("encrypted-unrar5")
-            << QFINDTESTDATA("data/archive-encrypted-unrar5.txt") << 7
+            << QFINDTESTDATA("data/archive-encrypted-unrar5.txt") << 7 << false << 0
             << 2 << QStringLiteral("rartest/file2.txt") << false << true << QString() << (qulonglong) 14 << (qulonglong) 32 << QStringLiteral("2016-03-21T17:03:36");
 
     QTest::newRow("recovery-record-unrar5")
-            << QFINDTESTDATA("data/archive-recovery-record-unrar5.txt") << 3
+            << QFINDTESTDATA("data/archive-recovery-record-unrar5.txt") << 3 << false << 0
             << 0 << QStringLiteral("file1.txt") << false << false << QString() << (qulonglong) 32 << (qulonglong) 33 << QStringLiteral("2015-07-26T19:04:38");
 
     QTest::newRow("corrupt-archive-unrar5")
-            << QFINDTESTDATA("data/archive-corrupt-file-header-unrar5.txt") << 8
+            << QFINDTESTDATA("data/archive-corrupt-file-header-unrar5.txt") << 8 << false << 0
             << 6 << QStringLiteral("dir1/") << true << false << QString() << (qulonglong) 0 << (qulonglong) 0 << QStringLiteral("2015-05-14T01:45:24");
 
+    //Note: The number of entries will be the total number of all entries in all volumes, i.e. if a file spans 3 volumes it will count as 3 entries.
+    QTest::newRow("multivolume-archive-unrar5")
+            << QFINDTESTDATA("data/archive-multivol-unrar5.txt") << 6 << true << 5
+            << 5 << QStringLiteral("largefile2") << false << false << QString() << (qulonglong) 2097152 << (qulonglong) 11231 << QStringLiteral("2016-07-17T11:26:19");
+
     // Unrar 4 tests
 
     QTest::newRow("normal-file-unrar4")
-            << QFINDTESTDATA("data/archive-with-symlink-unrar4.txt") << 8
+            << QFINDTESTDATA("data/archive-with-symlink-unrar4.txt") << 8 << false << 0
             << 2 << QStringLiteral("rartest/file2.txt") << false << false << QString() << (qulonglong) 14 << (qulonglong) 23 << QStringLiteral("2016-03-21T08:57:00");
 
     QTest::newRow("symlink-unrar4")
-            << QFINDTESTDATA("data/archive-with-symlink-unrar4.txt") << 8
+            << QFINDTESTDATA("data/archive-with-symlink-unrar4.txt") << 8 << false << 0
             << 3 << QStringLiteral("rartest/linktofile1.txt") << false << false << QStringLiteral("file1.txt") << (qulonglong) 9 << (qulonglong) 9 << QStringLiteral("2016-03-21T08:58:00");
 
     QTest::newRow("encrypted-unrar4")
-            << QFINDTESTDATA("data/archive-encrypted-unrar4.txt") << 7
+            << QFINDTESTDATA("data/archive-encrypted-unrar4.txt") << 7 << false << 0
             << 2 << QStringLiteral("rartest/file2.txt") << false << true << QString() << (qulonglong) 14 << (qulonglong) 32 << QStringLiteral("2016-03-21T17:03:00");
 
     QTest::newRow("recovery-record-unrar4")
-            << QFINDTESTDATA("data/archive-recovery-record-unrar4.txt") << 3
+            << QFINDTESTDATA("data/archive-recovery-record-unrar4.txt") << 3 << false << 0
             << 0 << QStringLiteral("file1.txt") << false << false << QString() << (qulonglong) 32 << (qulonglong) 33 << QStringLiteral("2015-07-26T19:04:00");
 
     QTest::newRow("corrupt-archive-unrar4")
-            << QFINDTESTDATA("data/archive-corrupt-file-header-unrar4.txt") << 8
+            << QFINDTESTDATA("data/archive-corrupt-file-header-unrar4.txt") << 8 << false << 0
             << 6 << QStringLiteral("dir1/") << true << false << QString() << (qulonglong) 0 << (qulonglong) 0 << QStringLiteral("2015-05-14T01:45:00");
 
+    //Note: The number of entries will be the total number of all entries in all volumes, i.e. if a file spans 3 volumes it will count as 3 entries.
+    QTest::newRow("multivolume-archive-unrar4")
+            << QFINDTESTDATA("data/archive-multivol-unrar4.txt") << 6 << true << 5
+            << 5 << QStringLiteral("largefile2") << false << false << QString() << (qulonglong) 2097152 << (qulonglong) 11231 << QStringLiteral("2016-07-17T11:26:00");
+
     /*
      * Check that the plugin will not crash when reading corrupted archives, which
      * have lines such as "Unexpected end of archive" or "??? - the file header is
@@ -161,7 +177,7 @@ void CliRarTest::testList_data()
      * See bug 262857 and commit 2042997013432cdc6974f5b26d39893a21e21011.
      */
     QTest::newRow("corrupt-archive-unrar3")
-            << QFINDTESTDATA("data/archive-corrupt-file-header-unrar3.txt") << 1
+            << QFINDTESTDATA("data/archive-corrupt-file-header-unrar3.txt") << 1 << true << 1
             << 0 << QStringLiteral("some-file.ext") << false << false << QString() << (qulonglong) 732522496 << (qulonglong) 14851208 << QStringLiteral("2010-10-29T20:47:00");
 }
 
@@ -184,6 +200,12 @@ void CliRarTest::testList()
 
     QCOMPARE(signalSpy.count(), expectedEntriesCount);
 
+    QFETCH(bool, isMultiVolume);
+    QCOMPARE(rarPlugin->isMultiVolume(), isMultiVolume);
+
+    QFETCH(int, numberOfVolumes);
+    QCOMPARE(rarPlugin->numberOfVolumes(), numberOfVolumes);
+
     QFETCH(int, someEntryIndex);
     QVERIFY(someEntryIndex < signalSpy.count());
     ArchiveEntry entry = qvariant_cast<ArchiveEntry>(signalSpy.at(someEntryIndex).at(0));
@@ -212,80 +234,196 @@ void CliRarTest::testList()
     rarPlugin->deleteLater();
 }
 
+void CliRarTest::testListArgs_data()
+{
+    QTest::addColumn<QString>("archiveName");
+    QTest::addColumn<QString>("password");
+    QTest::addColumn<QStringList>("expectedArgs");
+
+    QTest::newRow("unencrypted")
+            << QStringLiteral("/tmp/foo.rar")
+            << QString()
+            << QStringList {
+                   QStringLiteral("vt"),
+                   QStringLiteral("-v"),
+                   QStringLiteral("/tmp/foo.rar")
+               };
+
+    QTest::newRow("header-encrypted")
+            << QStringLiteral("/tmp/foo.rar")
+            << QStringLiteral("1234")
+            << QStringList {
+                   QStringLiteral("vt"),
+                   QStringLiteral("-v"),
+                   QStringLiteral("-p1234"),
+                   QStringLiteral("/tmp/foo.rar")
+               };
+}
+
+void CliRarTest::testListArgs()
+{
+    QFETCH(QString, archiveName);
+    CliPlugin *plugin = new CliPlugin(this, {QVariant(archiveName)});
+    QVERIFY(plugin);
+
+    const QStringList listArgs = { QStringLiteral("vt"),
+                                   QStringLiteral("-v"),
+                                   QStringLiteral("$PasswordSwitch"),
+                                   QStringLiteral("$Archive") };
+
+    QFETCH(QString, password);
+    const auto replacedArgs = plugin->substituteListVariables(listArgs, password);
+
+    QFETCH(QStringList, expectedArgs);
+    QCOMPARE(replacedArgs, expectedArgs);
+
+    plugin->deleteLater();
+}
+
+void CliRarTest::testAddArgs_data()
+{
+    QTest::addColumn<QString>("archiveName");
+    QTest::addColumn<QString>("password");
+    QTest::addColumn<bool>("encryptHeader");
+    QTest::addColumn<int>("compressionLevel");
+    QTest::addColumn<ulong>("volumeSize");
+    QTest::addColumn<QStringList>("expectedArgs");
+
+    QTest::newRow("unencrypted")
+            << QStringLiteral("/tmp/foo.rar")
+            << QString() << false << 3 << 0UL
+            << QStringList {
+                   QStringLiteral("a"),
+                   QStringLiteral("/tmp/foo.rar"),
+                   QStringLiteral("-m3")
+               };
+
+    QTest::newRow("encrypted")
+            << QStringLiteral("/tmp/foo.rar")
+            << QStringLiteral("1234") << false << 3 << 0UL
+            << QStringList {
+                   QStringLiteral("a"),
+                   QStringLiteral("/tmp/foo.rar"),
+                   QStringLiteral("-p1234"),
+                   QStringLiteral("-m3")
+               };
+
+    QTest::newRow("header-encrypted")
+            << QStringLiteral("/tmp/foo.rar")
+            << QStringLiteral("1234") << true << 3 << 0UL
+            << QStringList {
+                   QStringLiteral("a"),
+                   QStringLiteral("/tmp/foo.rar"),
+                   QStringLiteral("-hp1234"),
+                   QStringLiteral("-m3")
+               };
+
+    QTest::newRow("multi-volume")
+            << QStringLiteral("/tmp/foo.rar")
+            << QString() << false << 3 << 2500UL
+            << QStringList {
+                   QStringLiteral("a"),
+                   QStringLiteral("/tmp/foo.rar"),
+                   QStringLiteral("-m3"),
+                   QStringLiteral("-v2500k")
+               };
+}
+
+void CliRarTest::testAddArgs()
+{
+    QFETCH(QString, archiveName);
+    CliPlugin *rarPlugin = new CliPlugin(this, {QVariant(archiveName)});
+    QVERIFY(rarPlugin);
+
+    const QStringList addArgs = { QStringLiteral("a"),
+                                  QStringLiteral("$Archive"),
+                                  QStringLiteral("$PasswordSwitch"),
+                                  QStringLiteral("$CompressionLevelSwitch"),
+                                  QStringLiteral("$MultiVolumeSwitch"),
+                                  QStringLiteral("$Files") };
+
+    QFETCH(QString, password);
+    QFETCH(bool, encryptHeader);
+    QFETCH(int, compressionLevel);
+    QFETCH(ulong, volumeSize);
+
+    QStringList replacedArgs = rarPlugin->substituteAddVariables(addArgs, {}, password, encryptHeader, compressionLevel, volumeSize);
+
+    QFETCH(QStringList, expectedArgs);
+    QCOMPARE(replacedArgs, expectedArgs);
+
+    rarPlugin->deleteLater();
+}
+
 void CliRarTest::testExtractArgs_data()
 {
     QTest::addColumn<QString>("archiveName");
     QTest::addColumn<QVariantList>("files");
     QTest::addColumn<bool>("preservePaths");
     QTest::addColumn<QString>("password");
-    QTest::addColumn<QString>("rootNode");
     QTest::addColumn<QStringList>("expectedArgs");
 
-    QTest::newRow("preserve paths, encrypted, root node")
+    QTest::newRow("preserve paths, encrypted")
             << QStringLiteral("/tmp/foo.rar")
             << QVariantList {
                    QVariant::fromValue(fileRootNodePair(QStringLiteral("aDir/b.txt"), QStringLiteral("aDir"))),
                    QVariant::fromValue(fileRootNodePair(QStringLiteral("c.txt"), QString()))
                }
-            << true << QStringLiteral("1234") << QStringLiteral("aDir")
+            << true << QStringLiteral("1234")
             << QStringList {
                    QStringLiteral("-kb"),
                    QStringLiteral("-p-"),
                    QStringLiteral("x"),
                    QStringLiteral("-p1234"),
-                   QStringLiteral("-apaDir"),
                    QStringLiteral("/tmp/foo.rar"),
                    QStringLiteral("aDir/b.txt"),
                    QStringLiteral("c.txt"),
                };
 
-    QTest::newRow("preserve paths, unencrypted, root node")
+    QTest::newRow("preserve paths, unencrypted")
             << QStringLiteral("/tmp/foo.rar")
             << QVariantList {
                    QVariant::fromValue(fileRootNodePair(QStringLiteral("aDir/b.txt"), QStringLiteral("aDir"))),
                    QVariant::fromValue(fileRootNodePair(QStringLiteral("c.txt"), QString()))
                }
-            << true << QString() << QStringLiteral("aDir")
+            << true << QString()
             << QStringList {
                    QStringLiteral("-kb"),
                    QStringLiteral("-p-"),
                    QStringLiteral("x"),
-                   QStringLiteral("-apaDir"),
                    QStringLiteral("/tmp/foo.rar"),
                    QStringLiteral("aDir/b.txt"),
                    QStringLiteral("c.txt"),
                };
 
-    QTest::newRow("without paths, encrypted, root node")
+    QTest::newRow("without paths, encrypted")
             << QStringLiteral("/tmp/foo.rar")
             << QVariantList {
                    QVariant::fromValue(fileRootNodePair(QStringLiteral("aDir/b.txt"), QStringLiteral("aDir"))),
                    QVariant::fromValue(fileRootNodePair(QStringLiteral("c.txt"), QString()))
                }
-            << false << QStringLiteral("1234") << QStringLiteral("aDir")
+            << false << QStringLiteral("1234")
             << QStringList {
                    QStringLiteral("-kb"),
                    QStringLiteral("-p-"),
                    QStringLiteral("e"),
                    QStringLiteral("-p1234"),
-                   QStringLiteral("-apaDir"),
                    QStringLiteral("/tmp/foo.rar"),
                    QStringLiteral("aDir/b.txt"),
                    QStringLiteral("c.txt"),
                };
 
-    QTest::newRow("without paths, unencrypted, root node")
+    QTest::newRow("without paths, unencrypted")
             << QStringLiteral("/tmp/foo.rar")
             << QVariantList {
                    QVariant::fromValue(fileRootNodePair(QStringLiteral("aDir/b.txt"), QStringLiteral("aDir"))),
                    QVariant::fromValue(fileRootNodePair(QStringLiteral("c.txt"), QString()))
                }
-            << false << QString() << QStringLiteral("aDir")
+            << false << QString()
             << QStringList {
                    QStringLiteral("-kb"),
                    QStringLiteral("-p-"),
                    QStringLiteral("e"),
-                   QStringLiteral("-apaDir"),
                    QStringLiteral("/tmp/foo.rar"),
                    QStringLiteral("aDir/b.txt"),
                    QStringLiteral("c.txt"),
@@ -302,16 +440,14 @@ void CliRarTest::testExtractArgs()
                                       QStringLiteral("-p-"),
                                       QStringLiteral("$PreservePathSwitch"),
                                       QStringLiteral("$PasswordSwitch"),
-                                      QStringLiteral("$RootNodeSwitch"),
                                       QStringLiteral("$Archive"),
                                       QStringLiteral("$Files") };
 
     QFETCH(QVariantList, files);
     QFETCH(bool, preservePaths);
     QFETCH(QString, password);
-    QFETCH(QString, rootNode);
 
-    QStringList replacedArgs = rarPlugin->substituteCopyVariables(extractArgs, files, preservePaths, password, rootNode);
+    QStringList replacedArgs = rarPlugin->substituteCopyVariables(extractArgs, files, preservePaths, password);
     QVERIFY(replacedArgs.size() >= extractArgs.size());
 
     QFETCH(QStringList, expectedArgs);
