@@ -38,9 +38,11 @@ namespace Kerfuffle
 {
 ReadOnlyArchiveInterface::ReadOnlyArchiveInterface(QObject *parent, const QVariantList & args)
         : QObject(parent)
+        , m_numberOfVolumes(0)
         , m_waitForFinishedSignal(false)
         , m_isHeaderEncryptionEnabled(false)
         , m_isCorrupt(false)
+        , m_isMultiVolume(false)
 {
     qCDebug(ARK) << "Created read-only interface for" << args.first().toString();
     m_filename = args.first().toString();
@@ -65,17 +67,6 @@ bool ReadOnlyArchiveInterface::isReadOnly() const
     return true;
 }
 
-bool ReadOnlyArchiveInterface::isCliBased() const
-{
-    return false;
-}
-
-bool ReadOnlyArchiveInterface::findExecutables(bool isReadWrite)
-{
-    Q_UNUSED(isReadWrite)
-    return true;
-}
-
 bool ReadOnlyArchiveInterface::open()
 {
     return true;
@@ -124,6 +115,26 @@ bool ReadOnlyArchiveInterface::isCorrupt() const
     return m_isCorrupt;
 }
 
+bool ReadOnlyArchiveInterface::isMultiVolume() const
+{
+    return m_isMultiVolume;
+}
+
+void ReadOnlyArchiveInterface::setMultiVolume(bool value)
+{
+    m_isMultiVolume = value;
+}
+
+int ReadOnlyArchiveInterface::numberOfVolumes() const
+{
+    return m_numberOfVolumes;
+}
+
+QString ReadOnlyArchiveInterface::multiVolumeName() const
+{
+    return filename();
+}
+
 ReadWriteArchiveInterface::ReadWriteArchiveInterface(QObject *parent, const QVariantList & args)
         : ReadOnlyArchiveInterface(parent, args)
 {
