@@ -62,6 +62,9 @@ public:
      */
     QString password() const;
 
+    bool isMultiVolume() const;
+    int numberOfVolumes() const;
+
     /**
      * Returns whether the file can only be read.
      *
@@ -75,13 +78,13 @@ public:
     /**
      * List archive contents.
      * This runs the process of reading archive contents.
-     * When subclassing, you can block as long as you need, the function runs
-     * in its own thread.
+     * When subclassing, you can block as long as you need (unless you called setWaitForFinishedSignal(true)).
      * @returns whether the listing succeeded.
      * @note If returning false, make sure to emit the error() signal beforewards to notify
      * the user of the error condition.
      */
     virtual bool list() = 0;
+    virtual bool testArchive() = 0;
     void setPassword(const QString &password);
     void setHeaderEncryptionEnabled(bool enabled);
 
@@ -90,8 +93,7 @@ public:
      * Globally recognized extraction options:
      * @li PreservePaths - preserve file paths (extract flat if false)
      * @li RootNode - node in the archive which will correspond to the @arg destinationDirectory
-     * When subclassing, you can block as long as you need, the function runs
-     * in its own thread.
+     * When subclassing, you can block as long as you need (unless you called setWaitForFinishedSignal(true)).
      * @returns whether the listing succeeded.
      * @note If returning false, make sure to emit the error() signal beforewards to notify
      * the user of the error condition.
@@ -103,10 +105,9 @@ public:
     virtual bool doSuspend();
     virtual bool doResume();
 
-    virtual bool isCliBased() const;
-    virtual bool findExecutables(bool isReadWrite);
-
     bool isHeaderEncryptionEnabled() const;
+    virtual QString multiVolumeName() const;
+    void setMultiVolume(bool value);
 
 signals:
     void cancelled();
@@ -117,20 +118,20 @@ signals:
     void info(const QString &info);
     void finished(bool result);
     void userQuery(Query *query);
+    void testSuccess();
 
 protected:
 
     /**
-     * Setting this option to true will not exit the thread with the
-     * exit of the various functions, but rather when finished(bool) is
-     * called. Doing this one can use the event loop easily while doing
-     * the operation.
+     * Setting this option to true will not run the functions in their own thread.
+     * Instead it will be necessary to call finished(bool) when the operation is actually finished.
      */
     void setWaitForFinishedSignal(bool value);
 
     void setCorrupt(bool isCorrupt);
     bool isCorrupt() const;
     QString m_comment;
+    int m_numberOfVolumes;
 
 private:
     QString m_filename;
@@ -138,6 +139,7 @@ private:
     bool m_waitForFinishedSignal;
     bool m_isHeaderEncryptionEnabled;
     bool m_isCorrupt;
+    bool m_isMultiVolume;
 };
 
 class KERFUFFLE_EXPORT ReadWriteArchiveInterface: public ReadOnlyArchiveInterface
@@ -153,6 +155,7 @@ public:
     //contain
     virtual bool addFiles(const QStringList & files, const CompressionOptions& options) = 0;
     virtual bool deleteFiles(const QList<QVariant> & files) = 0;
+    virtual bool addComment(const QString &comment) = 0;
 };
 
 } // namespace Kerfuffle
