@@ -35,7 +35,10 @@ public:
     virtual void dragMoveEvent(class QDragMoveEvent * event) Q_DECL_OVERRIDE;
     virtual void startDrag(Qt::DropActions supportedActions) Q_DECL_OVERRIDE;
 
-    void setModel(QAbstractItemModel *model) Q_DECL_OVERRIDE;
+    /**
+     * Set whether the view should accept drop events.
+     */
+    void setDropsEnabled(bool enabled);
 };
 
 #endif /* ARCHIVEVIEW_H */
