@@ -287,8 +287,6 @@ void Part::setupView()
 
     m_view->setModel(m_model);
 
-    m_view->setSortingEnabled(true);
-
     connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged,
             this, &Part::updateActions);
     connect(m_view->selectionModel(), &QItemSelectionModel::selectionChanged,
@@ -676,14 +674,11 @@ bool Part::openFile()
         job->start();
     } else {
         updateActions();
+        m_view->setDropsEnabled(true);
     }
 
     m_infoPanel->setIndex(QModelIndex());
 
-    if (arguments().metaData()[QStringLiteral("showExtractDialog")] == QLatin1String("true")) {
-        QTimer::singleShot(0, this, &Part::slotShowExtractionDialog);
-    }
-
     const QString password = arguments().metaData()[QStringLiteral("encryptionPassword")];
     if (!password.isEmpty()) {
         m_model->encryptArchive(password,
@@ -810,6 +805,8 @@ void Part::slotLoadingFinished(KJob *job)
 
     // After loading all files, resize the columns to fit all fields
     m_view->header()->resizeSections(QHeaderView::ResizeToContents);
+    // Now we can start accepting drops in the archive view.
+    m_view->setDropsEnabled(true);
 
     updateActions();
 
@@ -835,6 +832,10 @@ void Part::slotLoadingFinished(KJob *job)
             displayMsgWidget(KMessageWidget::Warning, xi18nc("@info", "Ark does not currently support ISO files with UDF filesystem."));
         }
     }
+
+    if (arguments().metaData()[QStringLiteral("showExtractDialog")] == QLatin1String("true")) {
+        QTimer::singleShot(0, this, &Part::slotShowExtractionDialog);
+    }
 }
 
 void Part::setReadyGui()
