@@ -118,7 +118,7 @@ ParameterList CliPlugin::parameterList() const
 
         p[PasswordPromptPattern] = QStringLiteral(" password: ");
         p[WrongPasswordPatterns] = QStringList() << QStringLiteral("incorrect password");
-        //p[ExtractionFailedPatterns] = QStringList() << "CRC failed";
+        p[ExtractionFailedPatterns] = QStringList() << QStringLiteral("unsupported compression method");
         p[CorruptArchivePatterns] = QStringList() << QStringLiteral("End-of-central-directory signature not found");
         p[DiskFullPatterns] = QStringList() << QStringLiteral("write error \\(disk full\\?\\)")
                                             << QStringLiteral("No space left on device");
